import unittest

class TestHpc(unittest.TestCase):
    def test___init__(self):
        # hpc = Hpc(config)
        assert False # TODO: implement your test here

    def test_bind_private_queue(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.bind_private_queue(cluster_id, duration, is_auto_renewal, name, pay_type, queue_name, type_id, type_name, update_time))
        assert False # TODO: implement your test here

    def test_bind_private_queue_request(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.bind_private_queue_request(cluster_id, duration, is_auto_renewal, name, pay_type, queue_name, type_id, type_name, update_time))
        assert False # TODO: implement your test here

    def test_bind_private_queue_validate(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.bind_private_queue_validate())
        assert False # TODO: implement your test here

    def test_create_cluster(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.create_cluster(account_service, cluster_id, cluster_name, create_time, cur_cpu, deploy_mode, instance_id, instance_image, nas_id, nas_path, paid_period, paid_type, scheduler_type, software_info, status, status_time, tasks_running, tasks_total, user_name))
        assert False # TODO: implement your test here

    def test_create_cluster_request(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.create_cluster_request(account_service, cluster_id, cluster_name, create_time, cur_cpu, deploy_mode, instance_id, instance_image, nas_id, nas_path, paid_period, paid_type, scheduler_type, software_info, status, status_time, tasks_running, tasks_total, user_name))
        assert False # TODO: implement your test here

    def test_create_cluster_validate(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.create_cluster_validate())
        assert False # TODO: implement your test here

    def test_create_job_file(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.create_job_file(cluster_id, file_type, file_value, target_file))
        assert False # TODO: implement your test here

    def test_create_job_file_request(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.create_job_file_request(cluster_id, file_type, file_value, target_file))
        assert False # TODO: implement your test here

    def test_create_job_file_validate(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.create_job_file_validate())
        assert False # TODO: implement your test here

    def test_create_ldap_user(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.create_ldap_user(cn, description, gid_number, given_name, home_directory, mail, object_class, ou, parent_dn, password, sn, uid, uid_number))
        assert False # TODO: implement your test here

    def test_create_ldap_user_request(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.create_ldap_user_request(cn, description, gid_number, given_name, home_directory, mail, object_class, ou, parent_dn, password, sn, uid, uid_number))
        assert False # TODO: implement your test here

    def test_create_ldap_user_validate(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.create_ldap_user_validate())
        assert False # TODO: implement your test here

    def test_delete_cluster(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.delete_cluster(run_user))
        assert False # TODO: implement your test here

    def test_delete_cluster_request(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.delete_cluster_request(run_user))
        assert False # TODO: implement your test here

    def test_delete_cluster_validate(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.delete_cluster_validate())
        assert False # TODO: implement your test here

    def test_delete_jobs(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.delete_jobs(cluster_id, job_ids))
        assert False # TODO: implement your test here

    def test_delete_jobs_request(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.delete_jobs_request(cluster_id, job_ids))
        assert False # TODO: implement your test here

    def test_delete_jobs_validate(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.delete_jobs_validate())
        assert False # TODO: implement your test here

    def test_disable_hpc(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.disable_hpc(user_id))
        assert False # TODO: implement your test here

    def test_disable_hpc_request(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.disable_hpc_request(user_id))
        assert False # TODO: implement your test here

    def test_disable_hpc_validate(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.disable_hpc_validate())
        assert False # TODO: implement your test here

    def test_enable_hpc(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.enable_hpc(user_id))
        assert False # TODO: implement your test here

    def test_enable_hpc_request(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.enable_hpc_request(user_id))
        assert False # TODO: implement your test here

    def test_enable_hpc_validate(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.enable_hpc_validate())
        assert False # TODO: implement your test here

    def test_get_cost(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.get_cost(action, expires, package_month, plan_id, prod_id, queue_type, usage_time, zone))
        assert False # TODO: implement your test here

    def test_get_cost_request(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.get_cost_request(action, expires, package_month, plan_id, prod_id, queue_type, usage_time, zone))
        assert False # TODO: implement your test here

    def test_get_cost_validate(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.get_cost_validate())
        assert False # TODO: implement your test here

    def test_get_current_queue(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.get_current_queue(user_id))
        assert False # TODO: implement your test here

    def test_get_current_queue_request(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.get_current_queue_request(user_id))
        assert False # TODO: implement your test here

    def test_get_current_queue_validate(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.get_current_queue_validate())
        assert False # TODO: implement your test here

    def test_get_hpc_status(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.get_hpc_status())
        assert False # TODO: implement your test here

    def test_get_hpc_status_request(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.get_hpc_status_request())
        assert False # TODO: implement your test here

    def test_get_hpc_status_validate(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.get_hpc_status_validate())
        assert False # TODO: implement your test here

    def test_get_job_detail(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.get_job_detail())
        assert False # TODO: implement your test here

    def test_get_job_detail_request(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.get_job_detail_request())
        assert False # TODO: implement your test here

    def test_get_job_detail_validate(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.get_job_detail_validate())
        assert False # TODO: implement your test here

    def test_get_login_node(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.get_login_node(run_user))
        assert False # TODO: implement your test here

    def test_get_login_node_request(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.get_login_node_request(run_user))
        assert False # TODO: implement your test here

    def test_get_login_node_validate(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.get_login_node_validate())
        assert False # TODO: implement your test here

    def test_get_meter(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.get_meter(action, aggregation, end_time, expires, instance_ids, metering_period, meters, start_time, time_zone, zone))
        assert False # TODO: implement your test here

    def test_get_meter_request(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.get_meter_request(action, aggregation, end_time, expires, instance_ids, metering_period, meters, start_time, time_zone, zone))
        assert False # TODO: implement your test here

    def test_get_meter_validate(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.get_meter_validate())
        assert False # TODO: implement your test here

    def test_get_product_billing_model(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.get_product_billing_model(action, expires, prod_id, zone))
        assert False # TODO: implement your test here

    def test_get_product_billing_model_request(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.get_product_billing_model_request(action, expires, prod_id, zone))
        assert False # TODO: implement your test here

    def test_get_product_billing_model_validate(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.get_product_billing_model_validate())
        assert False # TODO: implement your test here

    def test_get_queue_types(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.get_queue_types())
        assert False # TODO: implement your test here

    def test_get_queue_types_request(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.get_queue_types_request())
        assert False # TODO: implement your test here

    def test_get_queue_types_validate(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.get_queue_types_validate())
        assert False # TODO: implement your test here

    def test_is_available_queue(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.is_available_queue(queue_name, user_id))
        assert False # TODO: implement your test here

    def test_is_available_queue_request(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.is_available_queue_request(queue_name, user_id))
        assert False # TODO: implement your test here

    def test_is_available_queue_validate(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.is_available_queue_validate())
        assert False # TODO: implement your test here

    def test_list_cluster(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.list_cluster(action, expires, run_user, zone))
        assert False # TODO: implement your test here

    def test_list_cluster_request(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.list_cluster_request(action, expires, run_user, zone))
        assert False # TODO: implement your test here

    def test_list_cluster_validate(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.list_cluster_validate())
        assert False # TODO: implement your test here

    def test_list_jobs(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.list_jobs(action, cluster_id, expires, job_state, run_user, zone))
        assert False # TODO: implement your test here

    def test_list_jobs_request(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.list_jobs_request(action, cluster_id, expires, job_state, run_user, zone))
        assert False # TODO: implement your test here

    def test_list_jobs_validate(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.list_jobs_validate())
        assert False # TODO: implement your test here

    def test_list_users(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.list_users(org_dn, username))
        assert False # TODO: implement your test here

    def test_list_users_request(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.list_users_request(org_dn, username))
        assert False # TODO: implement your test here

    def test_list_users_validate(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.list_users_validate())
        assert False # TODO: implement your test here

    def test_modify_ldap_password(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.modify_ldap_password(new_password, old_password, user_dn))
        assert False # TODO: implement your test here

    def test_modify_ldap_password_request(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.modify_ldap_password_request(new_password, old_password, user_dn))
        assert False # TODO: implement your test here

    def test_modify_ldap_password_validate(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.modify_ldap_password_validate())
        assert False # TODO: implement your test here

    def test_reg_login_node(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.reg_login_node(inst_ib_ip, runas_user))
        assert False # TODO: implement your test here

    def test_reg_login_node_request(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.reg_login_node_request(inst_ib_ip, runas_user))
        assert False # TODO: implement your test here

    def test_reg_login_node_validate(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.reg_login_node_validate())
        assert False # TODO: implement your test here

    def test_stop_jobs(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.stop_jobs(cluster_id, job_ids))
        assert False # TODO: implement your test here

    def test_stop_jobs_request(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.stop_jobs_request(cluster_id, job_ids))
        assert False # TODO: implement your test here

    def test_stop_jobs_validate(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.stop_jobs_validate())
        assert False # TODO: implement your test here

    def test_submit_job(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.submit_job(action, cluster_id, cmd_line, name, priority, queue_name, resource_limit, run_user, stderr_redirect_path, stdout_redirect_path, zone))
        assert False # TODO: implement your test here

    def test_submit_job_request(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.submit_job_request(action, cluster_id, cmd_line, name, priority, queue_name, resource_limit, run_user, stderr_redirect_path, stdout_redirect_path, zone))
        assert False # TODO: implement your test here

    def test_submit_job_validate(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.submit_job_validate())
        assert False # TODO: implement your test here

    def test_unbind_private_queue(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.unbind_private_queue(id))
        assert False # TODO: implement your test here

    def test_unbind_private_queue_request(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.unbind_private_queue_request(id))
        assert False # TODO: implement your test here

    def test_unbind_private_queue_validate(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.unbind_private_queue_validate())
        assert False # TODO: implement your test here

    def test_unreg_login_node(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.unreg_login_node(run_user))
        assert False # TODO: implement your test here

    def test_unreg_login_node_request(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.unreg_login_node_request(run_user))
        assert False # TODO: implement your test here

    def test_unreg_login_node_validate(self):
        # hpc = Hpc(config)
        # self.assertEqual(expected, hpc.unreg_login_node_validate())
        assert False # TODO: implement your test here

if __name__ == '__main__':
    unittest.main()



# +-------------------------------------------------------------------------
# | Copyright (C) 2016 Yunify, Inc.
# +-------------------------------------------------------------------------
# | Licensed under the Apache License, Version 2.0 (the "License");
# | you may not use this work except in compliance with the License.
# | You may obtain a copy of the License in the LICENSE file, or at:
# |
# | http://www.apache.org/licenses/LICENSE-2.0
# |
# | Unless required by applicable law or agreed to in writing, software
# | distributed under the License is distributed on an "AS IS" BASIS,
# | WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# | See the License for the specific language governing permissions and
# | limitations under the License.
# +-------------------------------------------------------------------------
# -*- coding: utf-8 -*-

import hmac
import base64
import logging
import hashlib
import time
import sys
# from pytz import timezone
# from datetime import datetime
if sys.version_info.major == 2:
    from urllib import quote, unquote, urlencode, quote_plus
    from urlparse import urlparse, parse_qs, urlunparse
else:
    from urllib.parse import quote, unquote, urlencode, quote_plus, urlparse, parse_qs, urlunparse
from qingcloud_hpc.build_request import Builder
from qingcloud_hpc.cli_utils.helper import url_quote

ISO8601 = '%Y-%m-%dT%H:%M:%SZ'


def process_canonical_request(request):
    hex_encode = hex_encode_md5_hash(request.data)
    parsed_url = urlparse(request.url)
    canonical_uri = process_canonical_uri(parsed_url[2])
    canonical_query_string = process_canonical_query_string(parse_qs(parsed_url[4]))
    return "%s\n%s\n%s\n%s" % (request.method.upper(), canonical_uri, canonical_query_string, hex_encode)


def process_canonical_query_string(query):
    # print "process_canonical_query_string query [%s:%s] " % (type(query), query)
    params = []
    for param in query:
        params.append(param)
    params.sort()

    canonical_query_param = []
    for key in params:
        value = query[key]
        k = quote(key)
        if type(value) is list:
            value.sort()
            for v in value:
                # print "k,v [%s:%s], type(v) = %s " % (k, v, type(v))
                kv = k + "=" + quote(str(v))
                canonical_query_param.append(kv)
        else:
            kv = k + "=" + quote(str(value))
            canonical_query_param.append(kv)

    return '&'.join(canonical_query_param)


def process_canonical_uri(path):
    pattens = unquote(path).split('/')
    uri = []
    for v in pattens:
        uri.append(quote(v))
    url_path = "/".join(uri)

    if url_path[-1] != '/':
        url_path = url_path + "/"

    return url_path


def hex_encode_md5_hash(data):
    if sys.version_info.major == 2:
        if not data:
            data = ""
    else:
        if not data:
            data = "".encode("utf-8")
        else:
            data = data.encode("utf-8")
    md5 = hashlib.md5()
    md5.update(data)
    return md5.hexdigest()


class Request:

    def __init__(self, config, operation):
        self.req = Builder(config, operation).parse()
        self.access_key_id = config.qy_access_key_id
        self.secret_access_key = config.qy_secret_access_key
        self.zone = config.zone
        self.logger = logging.getLogger("hpc-sdk")
        # print self.req.method
        # print self.req.url
        # print self.req.headers
        # print self.req.files
        # print self.req.data
        # print self.req.json
        # print self.req.params
        # print self.req.auth
        # print self.req.cookies

    def __repr__(self):
        return "<Request %s>" % self.req.method

    def sign(self):
        parsed_url = list(urlparse(self.req.url))
        query = {"version": "1",
                 "signature_version": "1",
                 "signature_method": "HmacSHA256",
                 "access_key_id": self.access_key_id,
                 "timestamp": time.strftime(ISO8601, time.gmtime())}

        if len(parsed_url[4]) == 0:
            parsed_url[4] = urlencode(query)
        else:
            if parsed_url[4].find("timestamp=") != -1:
                del query["timestamp"]
            parsed_url[4] = parsed_url[4] + "&" + urlencode(query)

        self.req.url = urlunparse(parsed_url)
        print(self.req.url )

        sign = {"signature": self.calc_sign()}
        parsed_url[4] = parsed_url[4] + "&" + urlencode(sign)
        self.req.url = urlunparse(parsed_url)

        self.logger.debug(self.req.url)

        prepared = self.req.prepare()
        prepared.url = url_quote(prepared.url)

        # print "prepared.method = %s" % prepared.method
        # print "prepared.url = %s" % prepared.url
        # print "prepared.headers = %s" % prepared.headers
        # print "prepared._cookies = %s" % prepared._cookies
        # print "prepared.body = %s" % prepared.body

        return prepared

    def calc_sign(self):
        string_to_sign = process_canonical_request(self.req)
        # print "string_to_sign: %s" % string_to_sign
        print(string_to_sign)
        if sys.version_info.major == 2:
            h = hmac.new(
                self.secret_access_key,
                string_to_sign,
                digestmod=hashlib.sha256
            )
            signature = base64.b64encode(h.digest()).strip()
            return quote_plus(signature)
        else:
            h = hmac.new(self.secret_access_key.encode(encoding="utf-8"), digestmod=hashlib.sha256)
            h.update(string_to_sign.encode(encoding="utf-8"))
            sign = base64.b64encode(h.digest()).strip()
            signature = quote_plus(sign.decode())
            # signature = quote_plus(signature)
            print(signature)
            return signature




# +-------------------------------------------------------------------------
# | Copyright (C) 2016 Yunify, Inc.
# +-------------------------------------------------------------------------
# | Licensed under the Apache License, Version 2.0 (the "License");
# | you may not use this work except in compliance with the License.
# | You may obtain a copy of the License in the LICENSE file, or at:
# |
# | http://www.apache.org/licenses/LICENSE-2.0
# |
# | Unless required by applicable law or agreed to in writing, software
# | distributed under the License is distributed on an "AS IS" BASIS,
# | WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# | See the License for the specific language governing permissions and
# | limitations under the License.
# +-------------------------------------------------------------------------
# -*- coding: utf-8 -*-

import logging

from qingcloud_hpc.constant import PART_SIZE


class Unpacker(dict):

    def __init__(self, res):
        super(Unpacker, self).__init__()
        self.res = res
        self.status_code = res.status_code
        self.logger = logging.getLogger("hpc-sdk")
        self.logger.debug("%s: %s" % ("status_code", self.status_code))
        self.unpack_response_body()

    @property
    def headers(self):
        return self.res.headers

    @property
    def content(self):
        return self.res.content

    @property
    def ok(self):
        return self.res.ok

    def unpack_response_body(self):
        # Body should be unpacked to json in these situations:
        # - status_code >= 400 and status_code < 600 (client error or server error)
        # - status_code >= 200 and status_code < 400 and content type is application/json
        # In other situations, body should not be unpacked for possibly large memory usage
        if not (self.res.ok
                and self.res.headers.get("Content-Type") != "application/json"):
            try:
                data = self.res.json()
            except ValueError:
                data = None
            if data:
                for (k, v) in data.items():
                    self[k] = v
                    self.logger.debug("%s: %s" % (k, v))

    def iter_content(self, chunk_size=PART_SIZE, decode_unicode=False):
        return self.res.iter_content(chunk_size, decode_unicode)



import setuptools

with open("qingcloud_hpc/README.md", "r") as fh:
  long_description = fh.read()
# python3 setup.py sdist bdist_wheel --universal

setuptools.setup(
    name="qingcloud_hpc",
    version="0.0.1",
    author="Qingcloud.HPC",
    author_email="siriusliang@yunify.com",
    description="Qingcloud hpc sdk",
    long_description=long_description,
    packages=setuptools.find_packages(),
    python_requires='>=2.7',
    install_requires=[
        'requests',
    ],
    classifiers=[
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: Apache Software License"
],

)


action_pair = {
    "HpcIaasGetChargeRecords": "get_charge_records",
    "HpcQueuestrategyAddEhpcQueueStrategy": "add_ehpc_queue_strategy",
    "HpcQueuestrategyDelEhpcQueueStrategy": "del_ehpc_queue_strategy",
    "HpcQueuestrategyModifyEhpcQueueStrategy": "modify_ehpc_queue_strategy",
    "HpcQueuestrategyEnableEhpcQueueStrategy": "enable_ehpc_queue_strategy",
    "HpcQueuestrategyGetEhpcQueueStrategyList": "get_ehpc_queue_strategy_list",
    "HpcQueuestrategyGetEhpcQueueStrategyLogList": "get_ehpc_queue_strategy_log_list",
    "HpcJobListJobs": "list_jobs",
    "HpcJobGetJobMonitor": "get_job_monitor",
    "HpcJobUpdateJobStatus": "update_job_status",
    "HpcJobPushJobMetrics": "push_job_metrics",
    "HpcJobGetJobDetail": "get_job_detail",
    "HpcJobCreateJobFile": "create_job_file",
    "HpcJobSubmitJob": "submit_job",
    "HpcSimulationSubmitSimulationJob": "submit_simulation_job",
    "HpcSimulationListSimulationJobs": "list_simulation_jobs",
    "HpcSimulationStopSimulationJobs": "stop_simulation_jobs",
    "HpcSimulationDeleteSimulationJobs": "delete_simulation_jobs",
    "HpcSimulationGetSimulationJobDetail": "get_simulation_job_detail",
    "HpcJobUpdateEhpcJobStatus": "update_ehpc_job_status",
    "HpcJobRecoverJobStatus": "recover_job_status",
    "HpcJobStopJobs": "stop_jobs",
    "HpcJobResumeJobs": "resume_jobs",
    "HpcJobDeleteJobs": "delete_jobs",
    "HpcJobtemplateJobCreateTemplate": "job_create_template",
    "HpcJobtemplateJobListTemplates": "job_list_templates",
    "HpcJobtemplateJobTemplateDetail": "job_template_detail",
    "HpcJobtemplateJobTemplateDelete": "job_template_delete",
    "HpcJobtemplateJobTemplateUpdate": "job_template_update",
    "HpcFiletemplateFileCreateTemplate": "file_create_template",
    "HpcFiletemplateFileListTemplates": "file_list_templates",
    "HpcFiletemplateFileTemplateDetail": "file_template_detail",
    "HpcFiletemplateFileTemplateDelete": "file_template_delete",
    "HpcFiletemplateFileTemplateUpdate": "file_template_update",
    "HpcOperationListOperation": "list_operation",
    "HpcOperationSimulationOperation": "simulation_operation",
    "HpcOperationHelloWorld": "hello_world",
    "HpcCliRunCmd": "run_cmd",
    "HpcUserListUsers": "list_users",
    "HpcUserDescribeHpcLoginAccountUser": "describe_hpc_login_account_user",
    "HpcUserAddUser": "add_user",
    "HpcUserModifyUser": "modify_user",
    "HpcUserDeleteUser": "delete_user",
    "HpcSubuserListSubusers": "list_subusers",
    "HpcPermissionEnableHpc": "enable_hpc",
    "HpcPermissionDisableHpc": "disable_hpc",
    "HpcPermissionGetHpcStatus": "get_hpc_status",
    "HpcBillingGetProductBillingModel": "get_product_billing_model",
    "HpcBillingGetCost": "get_cost",
    "HpcBillingGetMeter": "get_meter",
    "HpcBillingRemoteappNotify": "remoteapp_notify",
    "HpcBillingNotify": "notify",
    "HpcBillingListRemoteappLog": "list_remoteapp_log",
    "HpcQueueBindPrivateQueue": "bind_private_queue",
    "HpcQueueAddQueueType": "add_queue_type",
    "HpcQueueDelQueueTypes": "del_queue_types",
    "HpcQueueGetQueueTypeList": "get_queue_type_list",
    "HpcQueueGetQueueTypes": "get_queue_types",
    "HpcQueueAddPhyQueue": "add_phy_queue",
    "HpcQueueDelPhyQueues": "del_phy_queues",
    "HpcQueueGetPhyQueues": "get_phy_queues",
    "HpcQueueAddEhpcQueue": "add_ehpc_queue",
    "HpcQueueModifyEhpcQueue": "modify_ehpc_queue",
    "HpcQueueAddEhpcQueueNodes": "add_ehpc_queue_nodes",
    "HpcQueueRemoveEhpcQueueNodes": "remove_ehpc_queue_nodes",
    "HpcQueueDelEhpcQueues": "del_ehpc_queues",
    "HpcQueueGetEhpcQueueList": "get_ehpc_queue_list",
    "HpcQueueGetCurrentQueue": "get_current_queue",
    "HpcQueueUnbindPrivateQueue": "unbind_private_queue",
    "HpcQueueIsAvailableQueue": "is_available_queue",
    "HpcQueueUpdateQueueName": "update_queue_name",
    "HpcQueueDescribeQueue": "describe_queue",
    "HpcQueueGetQueueNodes": "get_queue_nodes",
    "HpcRentGetClusterPrivateResourceInfo": "get_cluster_private_resource_info",
    "HpcRentGetClusterShareResourceInfo": "get_cluster_share_resource_info",
    "HpcRentGetClusterBillInfo": "get_cluster_bill_info",
    "HpcRentGetRemoteappBillInfo": "get_remoteapp_bill_info",
    "HpcRentGetHpcFreeInfo": "get_hpc_free_info",
    "HpcClusterListCluster": "list_cluster",
    "HpcClusterGetHpcClusterDetail": "get_hpc_cluster_detail",
    "HpcClusterCreateCluster": "create_cluster",
    "HpcClusterDeleteCluster": "delete_cluster",
    "HpcClusterModifyCluster": "modify_cluster",
    "HpcClusterResizeClusterFee": "resize_cluster_fee",
    "HpcClusterResizeCluster": "resize_cluster",
    "HpcClusterStartCluster": "start_cluster",
    "HpcClusterStopCluster": "stop_cluster",
    "HpcClusterResumeCluster": "resume_cluster",
    "HpcClusterGetClusterNodes": "get_cluster_nodes",
    "HpcClusterAddClusterNodesFee": "add_cluster_nodes_fee",
    "HpcClusterAddClusterNodes": "add_cluster_nodes",
    "HpcClusterDeleteClusterNodes": "delete_cluster_nodes",
    "HpcClusterRestartClusterNodes": "restart_cluster_nodes",
    "HpcClusterGetNasInfo": "get_nas_info",
    "HpcClusterAssociateLoginNodeEip": "associate_login_node_eip",
    "HpcClusterDissociateLoginNodeEip": "dissociate_login_node_eip",
    "HpcClusterUpgradeCluster": "upgrade_cluster",
    "HpcClusterGetClusterConf": "get_cluster_conf",
    "HpcSoftwareGetGraphics": "get_graphics",
    "HpcSoftwareApplySoftware": "apply_software",
    "HpcSoftwareGetApply": "get_apply",
    "HpcSoftwareUpdateApply": "update_apply",
    "HpcSoftwareGetList": "get_list",
    "HpcSoftwareStartSoftware": "start_software",
    "HpcSoftwareStopSoftware": "stop_software",
    "HpcSoftwareModifySoftware": "modify_software",
    "HpcSoftwareDeleteSoftware": "delete_software",
    "HpcSoftwareAddSoftware": "add_software",
    "HpcSoftwareDeleteClass": "delete_class",
    "HpcSoftwareGetRemoteappLink": "get_remoteapp_link",
    "HpcSoftwareListClass": "list_class",
    "HpcSoftwareMark": "mark",
    "HpcSoftwareGetClusterSoftwareList": "get_cluster_software_list",
    "HpcSoftwareInstallClusterSoftwares": "install_cluster_softwares",
    "HpcSoftwareUninstallClusterSoftwares": "uninstall_cluster_softwares",
    "HpcProjectListProject": "list_project",
    "HpcProjectCreateProject": "create_project",
    "HpcProjectDestroyProject": "destroy_project",
    "HpcProjectModifyProject": "modify_project",
    "HpcProjectListMember": "list_member",
    "HpcProjectAddMember": "add_member",
    "HpcProjectDelMember": "del_member",
    "HpcProjectModifyMember": "modify_member",
    "HpcProjectListResource": "list_resource",
    "HpcProjectAddResource": "add_resource",
    "HpcProjectDelResource": "del_resource",
    "HpcProjectModifyResource": "modify_resource",
    "HpcProjectInitConfiguration": "init_configuration",
    "HpcProjectListProjectRole": "list_project_role",
    "HpcProjectCreateProjectRole": "create_project_role",
    "HpcProjectDestroyProjectRole": "destroy_project_role",
    "HpcProjectModifyProjectRole": "modify_project_role",
    "HpcProjectListProjectRuleGroup": "list_project_rule_group",
    "HpcProjectCreateProjectRuleGroup": "create_project_rule_group",
    "HpcProjectDestroyProjectRuleGroup": "destroy_project_rule_group",
    "HpcProjectModifyProjectRuleGroup": "modify_project_rule_group",
    "HpcProjectAddProjectRuleGroup": "add_project_rule_group",
    "HpcProjectDelProjectRuleGroup": "del_project_rule_group",
    "HpcProjectListProjectRule": "list_project_rule",
    "HpcProjectCreateProjectRule": "create_project_rule",
    "HpcProjectDestroyProjectRule": "destroy_project_rule",
    "HpcProjectModifyProjectRule": "modify_project_rule",
    "HpcProjectAddProjectRule": "add_project_rule",
    "HpcProjectDelProjectRule": "del_project_rule",
    "HpcEpmrListEhpcSubuserStor": "list_ehpc_subuser_stor",
    "HpcEpmrEnableEhpcSubuserStor": "enable_ehpc_subuser_stor",
    "HpcEpmrGetEhpcSubuserStorEnableStatus": "get_ehpc_subuser_stor_enable_status"
}

enable_action_pair = {
    "HpcIaasGetChargeRecords": "get_charge_records",
    "HpcQueuestrategyAddEhpcQueueStrategy": "add_ehpc_queue_strategy",
    "HpcQueuestrategyDelEhpcQueueStrategy": "del_ehpc_queue_strategy",
    "HpcQueuestrategyModifyEhpcQueueStrategy": "modify_ehpc_queue_strategy",
    "HpcQueuestrategyEnableEhpcQueueStrategy": "enable_ehpc_queue_strategy",
    "HpcQueuestrategyGetEhpcQueueStrategyList": "get_ehpc_queue_strategy_list",
    "HpcQueuestrategyGetEhpcQueueStrategyLogList": "get_ehpc_queue_strategy_log_list",
    "HpcJobListJobs": "list_jobs",
    "HpcJobGetJobMonitor": "get_job_monitor",
    "HpcJobUpdateJobStatus": "update_job_status",
    "HpcJobPushJobMetrics": "push_job_metrics",
    "HpcJobGetJobDetail": "get_job_detail",
    "HpcJobCreateJobFile": "create_job_file",
    "HpcJobSubmitJob": "submit_job",
    "HpcSimulationSubmitSimulationJob": "submit_simulation_job",
    "HpcSimulationListSimulationJobs": "list_simulation_jobs",
    "HpcSimulationStopSimulationJobs": "stop_simulation_jobs",
    "HpcSimulationDeleteSimulationJobs": "delete_simulation_jobs",
    "HpcSimulationGetSimulationJobDetail": "get_simulation_job_detail",
    "HpcJobUpdateEhpcJobStatus": "update_ehpc_job_status",
    "HpcJobRecoverJobStatus": "recover_job_status",
    "HpcJobStopJobs": "stop_jobs",
    "HpcJobResumeJobs": "resume_jobs",
    "HpcJobDeleteJobs": "delete_jobs",
    "HpcJobtemplateJobCreateTemplate": "job_create_template",
    "HpcJobtemplateJobListTemplates": "job_list_templates",
    "HpcJobtemplateJobTemplateDetail": "job_template_detail",
    "HpcJobtemplateJobTemplateDelete": "job_template_delete",
    "HpcJobtemplateJobTemplateUpdate": "job_template_update",
    "HpcFiletemplateFileCreateTemplate": "file_create_template",
    "HpcFiletemplateFileListTemplates": "file_list_templates",
    "HpcFiletemplateFileTemplateDetail": "file_template_detail",
    "HpcFiletemplateFileTemplateDelete": "file_template_delete",
    "HpcFiletemplateFileTemplateUpdate": "file_template_update",
    "HpcOperationListOperation": "list_operation",
    "HpcOperationSimulationOperation": "simulation_operation",
    "HpcOperationHelloWorld": "hello_world",
    "HpcCliRunCmd": "run_cmd",
    "HpcUserListUsers": "list_users",
    "HpcUserDescribeHpcLoginAccountUser": "describe_hpc_login_account_user",
    "HpcUserAddUser": "add_user",
    "HpcUserModifyUser": "modify_user",
    "HpcUserDeleteUser": "delete_user",
    "HpcSubuserListSubusers": "list_subusers",
    "HpcPermissionEnableHpc": "enable_hpc",
    "HpcPermissionDisableHpc": "disable_hpc",
    "HpcPermissionGetHpcStatus": "get_hpc_status",
    "HpcBillingGetProductBillingModel": "get_product_billing_model",
    "HpcBillingGetCost": "get_cost",
    "HpcBillingGetMeter": "get_meter",
    "HpcBillingRemoteappNotify": "remoteapp_notify",
    "HpcBillingNotify": "notify",
    "HpcBillingListRemoteappLog": "list_remoteapp_log",
    "HpcQueueBindPrivateQueue": "bind_private_queue",
    "HpcQueueAddQueueType": "add_queue_type",
    "HpcQueueDelQueueTypes": "del_queue_types",
    "HpcQueueGetQueueTypeList": "get_queue_type_list",
    "HpcQueueGetQueueTypes": "get_queue_types",
    "HpcQueueAddPhyQueue": "add_phy_queue",
    "HpcQueueDelPhyQueues": "del_phy_queues",
    "HpcQueueGetPhyQueues": "get_phy_queues",
    "HpcQueueAddEhpcQueue": "add_ehpc_queue",
    "HpcQueueModifyEhpcQueue": "modify_ehpc_queue",
    "HpcQueueAddEhpcQueueNodes": "add_ehpc_queue_nodes",
    "HpcQueueRemoveEhpcQueueNodes": "remove_ehpc_queue_nodes",
    "HpcQueueDelEhpcQueues": "del_ehpc_queues",
    "HpcQueueGetEhpcQueueList": "get_ehpc_queue_list",
    "HpcQueueGetCurrentQueue": "get_current_queue",
    "HpcQueueUnbindPrivateQueue": "unbind_private_queue",
    "HpcQueueIsAvailableQueue": "is_available_queue",
    "HpcQueueUpdateQueueName": "update_queue_name",
    "HpcQueueDescribeQueue": "describe_queue",
    "HpcQueueGetQueueNodes": "get_queue_nodes",
    "HpcRentGetClusterPrivateResourceInfo": "get_cluster_private_resource_info",
    "HpcRentGetClusterShareResourceInfo": "get_cluster_share_resource_info",
    "HpcRentGetClusterBillInfo": "get_cluster_bill_info",
    "HpcRentGetRemoteappBillInfo": "get_remoteapp_bill_info",
    "HpcRentGetHpcFreeInfo": "get_hpc_free_info",
    "HpcClusterListCluster": "list_cluster",
    "HpcClusterGetHpcClusterDetail": "get_hpc_cluster_detail",
    "HpcClusterCreateCluster": "create_cluster",
    "HpcClusterDeleteCluster": "delete_cluster",
    "HpcClusterModifyCluster": "modify_cluster",
    "HpcClusterResizeClusterFee": "resize_cluster_fee",
    "HpcClusterResizeCluster": "resize_cluster",
    "HpcClusterStartCluster": "start_cluster",
    "HpcClusterStopCluster": "stop_cluster",
    "HpcClusterResumeCluster": "resume_cluster",
    "HpcClusterGetClusterNodes": "get_cluster_nodes",
    "HpcClusterAddClusterNodesFee": "add_cluster_nodes_fee",
    "HpcClusterAddClusterNodes": "add_cluster_nodes",
    "HpcClusterDeleteClusterNodes": "delete_cluster_nodes",
    "HpcClusterRestartClusterNodes": "restart_cluster_nodes",
    "HpcClusterGetNasInfo": "get_nas_info",
    "HpcClusterAssociateLoginNodeEip": "associate_login_node_eip",
    "HpcClusterDissociateLoginNodeEip": "dissociate_login_node_eip",
    "HpcClusterUpgradeCluster": "upgrade_cluster",
    "HpcClusterGetClusterConf": "get_cluster_conf",
    "HpcSoftwareGetGraphics": "get_graphics",
    "HpcSoftwareApplySoftware": "apply_software",
    "HpcSoftwareGetApply": "get_apply",
    "HpcSoftwareUpdateApply": "update_apply",
    "HpcSoftwareGetList": "get_list",
    "HpcSoftwareStartSoftware": "start_software",
    "HpcSoftwareStopSoftware": "stop_software",
    "HpcSoftwareModifySoftware": "modify_software",
    "HpcSoftwareDeleteSoftware": "delete_software",
    "HpcSoftwareAddSoftware": "add_software",
    "HpcSoftwareDeleteClass": "delete_class",
    "HpcSoftwareGetRemoteappLink": "get_remoteapp_link",
    "HpcSoftwareListClass": "list_class",
    "HpcSoftwareMark": "mark",
    "HpcSoftwareGetClusterSoftwareList": "get_cluster_software_list",
    "HpcSoftwareInstallClusterSoftwares": "install_cluster_softwares",
    "HpcSoftwareUninstallClusterSoftwares": "uninstall_cluster_softwares",
    "HpcProjectListProject": "list_project",
    "HpcProjectCreateProject": "create_project",
    "HpcProjectDestroyProject": "destroy_project",
    "HpcProjectModifyProject": "modify_project",
    "HpcProjectListMember": "list_member",
    "HpcProjectAddMember": "add_member",
    "HpcProjectDelMember": "del_member",
    "HpcProjectModifyMember": "modify_member",
    "HpcProjectListResource": "list_resource",
    "HpcProjectAddResource": "add_resource",
    "HpcProjectDelResource": "del_resource",
    "HpcProjectModifyResource": "modify_resource",
    "HpcProjectInitConfiguration": "init_configuration",
    "HpcProjectListProjectRole": "list_project_role",
    "HpcProjectCreateProjectRole": "create_project_role",
    "HpcProjectDestroyProjectRole": "destroy_project_role",
    "HpcProjectModifyProjectRole": "modify_project_role",
    "HpcProjectListProjectRuleGroup": "list_project_rule_group",
    "HpcProjectCreateProjectRuleGroup": "create_project_rule_group",
    "HpcProjectDestroyProjectRuleGroup": "destroy_project_rule_group",
    "HpcProjectModifyProjectRuleGroup": "modify_project_rule_group",
    "HpcProjectAddProjectRuleGroup": "add_project_rule_group",
    "HpcProjectDelProjectRuleGroup": "del_project_rule_group",
    "HpcProjectListProjectRule": "list_project_rule",
    "HpcProjectCreateProjectRule": "create_project_rule",
    "HpcProjectDestroyProjectRule": "destroy_project_rule",
    "HpcProjectModifyProjectRule": "modify_project_rule",
    "HpcProjectAddProjectRule": "add_project_rule",
    "HpcProjectDelProjectRule": "del_project_rule",
    "HpcEpmrListEhpcSubuserStor": "list_ehpc_subuser_stor",
    "HpcEpmrEnableEhpcSubuserStor": "enable_ehpc_subuser_stor",
    "HpcEpmrGetEhpcSubuserStorEnableStatus": "get_ehpc_subuser_stor_enable_status"
}